import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Container from 'reactstrap/lib/Container';
import Navbar from 'reactstrap/lib/Navbar';
import NavbarBrand from 'reactstrap/lib/NavbarBrand';
import Nav from 'reactstrap/lib/Nav';
import Dropdown from 'reactstrap/lib/Dropdown';
import DropdownToggle from 'reactstrap/lib/DropdownToggle';
import DropdownMenu from 'reactstrap/lib/DropdownMenu';
import DropdownItem from 'reactstrap/lib/DropdownItem';
import { IconLogoFooter } from '../icons/icon-logo-footer/icon-logo-footer';
import { LANG_NAMES } from '../../constants';
import { IconArrowDown } from '../icons/icon-arrow-down/icon-arrow-down';
import { changeLocation } from '../../helpers/change-location';
import './footer.scss';

export class Footer extends Component {
  static propTypes = {
    children: PropTypes.node.isRequired,
    locale: PropTypes.string.isRequired,
    className: PropTypes.string,
  };

  static defaultProps = {
    className: '',
  };

  state = {
    dropdownOpen: false,
  };

  toggle = () => {
    this.setState(prevState => ({
      dropdownOpen: !prevState.dropdownOpen,
    }));
  };

  changeLocale = (e) => {
    const newLocale = e.target.value;
    if (newLocale !== this.props.locale) {
      changeLocation(`/${newLocale}/`);
    }
  };

  render() {
    const { dropdownOpen } = this.state;
    const { locale, children, className } = this.props;
    return (
      <footer className={classNames('footer p-0 border-top pt-6 bg-white w-100', className)}>
        <Container>
          <Navbar>
            <NavbarBrand href="/">
              <IconLogoFooter />
            </NavbarBrand>
            <Nav>
              {children}
              <Dropdown isOpen={dropdownOpen} toggle={this.toggle}>
                <DropdownToggle nav className="p-0 pl-3_5 text-gray-dark-secondary">
                  {LANG_NAMES[locale]} <IconArrowDown />
                </DropdownToggle>
                <DropdownMenu className="language-dropdown">
                  {
                    Object.entries(LANG_NAMES).map(([loc, langName]) => (
                      <DropdownItem key={loc} value={loc} active={loc === locale} onClick={this.changeLocale}>
                        {langName}
                      </DropdownItem>
                    ))
                  }
                </DropdownMenu>
              </Dropdown>
            </Nav>
          </Navbar>
        </Container>
      </footer>
    );
  }
}
