import React from 'react';
import { Footer } from './footer';
import { changeLocation } from '../../helpers/change-location';

jest.mock('../../helpers/change-location');

describe('<Footer />', () => {
  const wrapper = shallow(<Footer locale="en-us">Hi footer</Footer>);

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  test('should toggle dropdown', () => {
    wrapper.instance().toggle();
    expect(wrapper.instance().state.dropdownOpen).toBe(true);
  });

  test('should not change location when locale equals new locale', () => {
    const event = {
      target: {
        value: 'en-us',
      },
    };
    wrapper.instance().changeLocale(event);
    expect(changeLocation).not.toHaveBeenCalled();
  });

  test('should change location when locale not equal new locale', () => {
    const event = {
      target: {
        value: 'ru-ru',
      },
    };
    wrapper.instance().changeLocale(event);
    expect(changeLocation).toBeCalledWith('/ru-ru/');
  });
});
