import React from 'react';
import { Tabs, Tab } from './tabs';

describe('<Tabs />', () => {
  describe('with uppercase labels', () => {
    test('should match snapshot', () => {
      const wrapper = shallow((
        <Tabs upper>
          <Tab label="test">tab content 1</Tab>
          <Tab label="test">tab content 2</Tab>
        </Tabs>
      ));

      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('with border', () => {
    test('should match snapshot', () => {
      const wrapper = shallow((
        <Tabs border>
          <Tab label="test">tab content 1</Tab>
          <Tab label="test">tab content 2</Tab>
        </Tabs>
      ));

      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('with flex items', () => {
    test('should match snapshot', () => {
      const wrapper = shallow((
        <Tabs flexItems>
          <Tab label="test">tab content 1</Tab>
          <Tab label="test">tab content 2</Tab>
        </Tabs>
      ));

      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('without tabId on Tab', () => {
    describe('without activeTab the first tab should to be active', () => {
      test('should match snapshot', () => {
        const wrapper = shallow((
          <Tabs>
            <Tab label="test">tab content 1</Tab>
            <Tab label="test">tab content 2</Tab>
          </Tabs>
        ));

        expect(wrapper).toMatchSnapshot();
      });
    });

    describe('with activeTab the right tab should to be active', () => {
      test('should match snapshot', () => {
        const wrapper = shallow((
          <Tabs activeTab={1}>
            <Tab label="test">tab content 1</Tab>
            <Tab label="test">tab content 2</Tab>
          </Tabs>
        ));

        expect(wrapper).toMatchSnapshot();
      });
    });
  });

  describe('with tabId on Tab', () => {
    describe('without activeTab the first tab should to be active', () => {
      test('should match snapshot', () => {
        const wrapper = shallow((
          <Tabs>
            <Tab label="test" tabId="first">tab content 1</Tab>
            <Tab label="test" tabId="second">tab content 2</Tab>
          </Tabs>
        ));

        expect(wrapper).toMatchSnapshot();
      });
    });

    describe('with activeTab the right tab should to be active', () => {
      test('should match snapshot', () => {
        const wrapper = shallow((
          <Tabs activeTab="second">
            <Tab label="test" tabId="first">tab content 1</Tab>
            <Tab label="test" tabId="second">tab content 2</Tab>
          </Tabs>
        ));

        expect(wrapper).toMatchSnapshot();
      });
    });
  });

  describe('toggle', () => {
    test('should select correct tab', () => {
      const wrapper = shallow((
        <Tabs>
          <Tab label="test">tab content 1</Tab>
          <Tab label="test">tab content 2</Tab>
          <span key="looool">Not a tab!</span>
        </Tabs>
      ));

      wrapper.instance().toggle(1);
      expect(wrapper.state().activeTab).toEqual(1);
    });
  });
});

describe('<Tab />', () => {
  test('should match snapshot', () => {
    const wrapper = shallow((
      <Tab label="test" tabId="first">tab content 1</Tab>
    ));

    expect(wrapper).toMatchSnapshot();
  });
});
